==> alliance-5.0-20020701.tar.gz: alliance-5.0/vex/src/vexdel.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
| Tool    :                     Vex                           |
|                                                             |
| File    :                   vexdel.c                        |
|                                                             |
| Date    :                   03.12.96                        |
|                                                             |
| Author  :               Jacomme Ludovic                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include "mut.h"
# include "aut.h"
# include "vex.h"

# include <stdio.h>
# include "vexdel.h"
# include "vexerror.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Varivexes                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                        Del  Functions                       |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                         Del Vex Expr                        |
|                                                             |
\------------------------------------------------------------*/

void delvexexpr( Expr )

  vexexpr *Expr;
{
  chain_list *ScanOper;

  if ( ! IsVexNodeAtom( Expr ) )
  {
    for ( ScanOper  = Expr->OPERAND;
          ScanOper != (chain_list *)0;
          ScanOper  = ScanOper->NEXT )
    {
      freevexexpr( GetVexOperand( ScanOper ) );
    }

    freechain( Expr->OPERAND );
  }

  freevexnode( Expr );
}

/*------------------------------------------------------------\
|                                                             |
|                         Del Vex Expr Number                 |
|                                                             |
\------------------------------------------------------------*/

void delvexexprnum( Expr, Number )

  vexexpr *Expr;
  int      Number;
{
  chain_list **PrevOper;
  chain_list  *ScanOper;
  int          Counter;

  if ( ! IsVexNodeAtom( Expr ) )
  {
    PrevOper = &Expr->OPERAND;
    Counter  = 0;

    for ( ScanOper  = Expr->OPERAND;
          ScanOper != (chain_list *)0;
          ScanOper  = ScanOper->NEXT )
    {
      if ( Counter == Number )
      {
        *PrevOper = ScanOper->NEXT;
        ScanOper->NEXT = (chain_list *)0;

        delvexexpr( GetVexOperand( ScanOper ) );
        freechain( ScanOper );

        return;
      }
      
      Counter  = Counter + 1;
      PrevOper = &ScanOper->NEXT;
      ScanOper = ScanOper->NEXT;
    }
  }
}

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/vex/src/vexdel.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
| Tool    :                     Vex                           |
|                                                             |
| File    :                   vexdel.c                        |
|                                                             |
| Date    :                   03.12.96                        |
|                                                             |
| Author  :               Jacomme Ludovic                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include "mut.h"
# include "aut.h"
# include "vex.h"

# include <stdio.h>
# include "vexdel.h"
# include "vexerror.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Varivexes                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                        Del  Functions                       |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                         Del Vex Expr                        |
|                                                             |
\------------------------------------------------------------*/

void delvexexpr( Expr )

  vexexpr *Expr;
{
  chain_list *ScanOper;

  if ( ! IsVexNodeAtom( Expr ) )
  {
    for ( ScanOper  = Expr->OPERAND;
          ScanOper != (chain_list *)0;
          ScanOper  = ScanOper->NEXT )
    {
      freevexexpr( GetVexOperand( ScanOper ) );
    }

    freechain( Expr->OPERAND );
  }

  freevexnode( Expr );
}

/*------------------------------------------------------------\
|                                                             |
|                         Del Vex Expr Number                 |
|                                                             |
\------------------------------------------------------------*/

void delvexexprnum( Expr, Number )

  vexexpr *Expr;
  int      Number;
{
  chain_list **PrevOper;
  chain_list  *ScanOper;
  int          Counter;

  if ( ! IsVexNodeAtom( Expr ) )
  {
    PrevOper = &Expr->OPERAND;
    Counter  = 0;

    for ( ScanOper  = Expr->OPERAND;
          ScanOper != (chain_list *)0;
          ScanOper  = ScanOper->NEXT )
    {
      if ( Counter == Number )
      {
        *PrevOper = ScanOper->NEXT;
        ScanOper->NEXT = (chain_list *)0;

        delvexexpr( GetVexOperand( ScanOper ) );
        freechain( ScanOper );

        return;
      }
      
      Counter  = Counter + 1;
      PrevOper = &ScanOper->NEXT;
      ScanOper = ScanOper->NEXT;
    }
  }
}
